==> openshift-model-tuned-5.12.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/TunedBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class TunedBuilder extends io.fabric8.openshift.api.model.tuned.v1.TunedFluentImpl<io.fabric8.openshift.api.model.tuned.v1.TunedBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.tuned.v1.Tuned,io.fabric8.openshift.api.model.tuned.v1.TunedBuilder>{
  public TunedBuilder() {
    this(false);
  }
  public TunedBuilder(java.lang.Boolean validationEnabled) {
    this(new Tuned(), validationEnabled);
  }
  public TunedBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedFluent<?> fluent) {
    this(fluent, false);
  }
  public TunedBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Tuned(), validationEnabled);
  }
  public TunedBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.Tuned instance) {
    this(fluent, instance, false);
  }
  public TunedBuilder(io.fabric8.openshift.api.model.tuned.v1.TunedFluent<?> fluent,io.fabric8.openshift.api.model.tuned.v1.Tuned instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TunedBuilder(io.fabric8.openshift.api.model.tuned.v1.Tuned instance) {
    this(instance,false);
  }
  public TunedBuilder(io.fabric8.openshift.api.model.tuned.v1.Tuned instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.tuned.v1.TunedFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.tuned.v1.Tuned build() {
    Tuned buildable = new Tuned(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    TunedBuilder that = (TunedBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-tuned-6.5.1-sources.jar: io/fabric8/openshift/api/model/tuned/v1/TunedBuilder.java <==
package io.fabric8.openshift.api.model.tuned.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class TunedBuilder extends TunedFluentImpl<TunedBuilder> implements VisitableBuilder<Tuned,TunedBuilder>{
  public TunedBuilder() {
    this(false);
  }
  public TunedBuilder(Boolean validationEnabled) {
    this(new Tuned(), validationEnabled);
  }
  public TunedBuilder(TunedFluent<?> fluent) {
    this(fluent, false);
  }
  public TunedBuilder(TunedFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Tuned(), validationEnabled);
  }
  public TunedBuilder(TunedFluent<?> fluent,Tuned instance) {
    this(fluent, instance, false);
  }
  public TunedBuilder(TunedFluent<?> fluent,Tuned instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public TunedBuilder(Tuned instance) {
    this(instance,false);
  }
  public TunedBuilder(Tuned instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  TunedFluent<?> fluent;
  Boolean validationEnabled;
  public Tuned build() {
    Tuned buildable = new Tuned(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
